@@ -32,22 +32,20 @@ if ! command -v abi-gen-uni &>/dev/null; then
     echo "abi-gen-uni could not be found. please check the official source from: https://www.npmjs.com/package/easy-abi-gen"
     cnpm i -g easy-abi-gen
 fi
-if ! command -v poa-solidity-flattener &>/dev/null; then
-    echo "poa-solidity-flattener could not be found, now it needs to install"
-    cnpm i -g poa-solidity-flattener
-fi
+
 {LISTP}
 
 """
 ITEM = """
 echo "🍯 Compiling from {COMPILE_COIN} 🧀"
-SOLC_VERSION={SOLVER} solc --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --overwrite {COMPILE_COIN}
+SOLC_VERSION={SOLVER} solc --evm-version byzantium --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --overwrite {COMPILE_COIN}
 echo "=> 🍺🍺🍺 {COMPILE_COIN}"
 """
 
 ITEMLINK = """
 echo "🍰 Compiling with LINK from {COMPILE_COIN} 🧀"
-SOLC_VERSION={SOLVER} solc --allow-paths {SOLCPATH} -o build --bin --bin-runtime --abi --optimize --metadata --libraries {FILES_CONFIG} --overwrite {COMPILE_COIN}
+#solc --optimize --bin MetaCoin.sol | solc --link --libraries TestLib:<address>
+SOLC_VERSION={SOLVER} solc --allow-paths {SOLCPATH} -o build  --optimize --bin --abi --link --libraries "{FILES_CONFIG}" --overwrite {COMPILE_COIN}
 echo "=> 🍥🍥🍥 {COMPILE_COIN}"
 """
 
@@ -65,7 +63,7 @@ abi-gen-uni --abibins {target_abi} --out "{outputfolder}" \
     --partials "{BUILDPATH}/factoryabi/PythonEthernum/partials/*.handlebars" \
     --template "{BUILDPATH}/factoryabi/PythonEthernum/contract.handlebars" \
     --language "Python"
-echo "==> compile abi to python 🚸✅"
+echo "==> generate abi to python --> 🧊"
 """
 
 ITEM_TRANSPILE_TS = """
@@ -80,7 +78,7 @@ abi-gen-uni --abibins "{target_abi}" --out "{outputfolder}" \
     --backend "web3" \
     --language "TypeScript"
 
-echo "==> compile abi to typescript 🚸✅"
+echo "==> generate abi to typescript --> 🧊"
 """
 ITEM_TRANSPILE_GO="""
 echo "==> 🚸 compile abi to golang"
@@ -93,5 +91,5 @@ fi
 
 abigen --abi "$BUILDPATH/build/$CLASSNAME.abi" --pkg $CLASSNAME --out "$GO_CONTRACT_SRC_PATH/$CLASSNAME/init.go"
 
-echo "==> compile abi to golang 🚸✅"
+echo "==> generate abi to golang --> 🧊"
 """
\ No newline at end of file
